@@ -12,8 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -162,11 +162,11 @@ class FirewallGroupDetailsView(tabs.TabView):
     def get_data(self):
         try:
             firewallgroup_id = self.kwargs['firewallgroup_id']
-            firewall_group = api_fwaas_v2.firewall_get(self.request,
-                                                       firewallgroup_id)
+            firewall_group = api_fwaas_v2.firewall_group_get(self.request,
+                                                             firewallgroup_id)
         except Exception:
             exceptions.handle(self.request,
-                              _('Unable to retrieve firewall details.'),
+                              _('Unable to retrieve firewall group details.'),
                               redirect=self.failure_url)
         return firewall_group
 
@@ -209,7 +209,7 @@ class UpdateRuleView(forms.ModalFormView):
 
     def get_initial(self):
         rule = self._get_object()
-        initial = rule.get_dict()
+        initial = rule.to_dict()
         protocol = initial['protocol']
         initial['protocol'] = protocol.upper() if protocol else 'ANY'
         initial['action'] = initial['action'].upper()
@@ -249,7 +249,7 @@ class UpdatePolicyView(forms.ModalFormView):
 
     def get_initial(self):
         policy = self._get_object()
-        initial = policy.get_dict()
+        initial = policy.to_dict()
         return initial
 
 
@@ -275,19 +275,18 @@ class UpdateFirewallView(forms.ModalFormView):
 
     @memoized.memoized_method
     def _get_object(self, *args, **kwargs):
-        firewall_id = self.kwargs['firewall_id']
+        fwg_id = self.kwargs['firewall_id']
         try:
-            firewall = api_fwaas_v2.firewall_get(self.request,
-                                                 firewall_id)
-            return firewall
+            fwg = api_fwaas_v2.firewall_group_get(self.request, fwg_id)
+            return fwg
         except Exception:
             redirect = self.success_url
-            msg = _('Unable to retrieve firewall details.')
+            msg = _('Unable to retrieve firewall group details.')
             exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_initial(self):
-        firewall = self._get_object()
-        initial = firewall.get_dict()
+        fwg = self._get_object()
+        initial = fwg.to_dict()
         return initial
 
 
@@ -299,7 +298,7 @@ class AddPortView(forms.ModalFormView):
     submit_label = _("Save Changes")
     submit_url = "horizon:project:firewalls_v2:addport"
     success_url = reverse_lazy("horizon:project:firewalls_v2:index")
-    page_title = _("Add port to FirewallGroup {{ name }}")
+    page_title = _("Add port to Firewall Group {{ name }}")
 
     def get_context_data(self, **kwargs):
         context = super(AddPortView, self).get_context_data(**kwargs)
@@ -315,8 +314,8 @@ class AddPortView(forms.ModalFormView):
     def _get_object(self, *args, **kwargs):
         firewallgroup_id = self.kwargs['firewallgroup_id']
         try:
-            firewallgroup = api_fwaas_v2.firewall_get(self.request,
-                                                      firewallgroup_id)
+            firewallgroup = api_fwaas_v2.firewall_group_get(self.request,
+                                                            firewallgroup_id)
             return firewallgroup
         except Exception:
             redirect = self.success_url
@@ -325,7 +324,7 @@ class AddPortView(forms.ModalFormView):
 
     def get_initial(self):
         firewallgroup = self._get_object()
-        initial = firewallgroup.get_dict()
+        initial = firewallgroup.to_dict()
         return initial
 
 
@@ -353,17 +352,17 @@ class RemovePortView(forms.ModalFormView):
     def _get_object(self, *args, **kwargs):
         firewallgroup_id = self.kwargs['firewallgroup_id']
         try:
-            firewallgroup = api_fwaas_v2.firewall_get(self.request,
-                                                      firewallgroup_id)
+            firewallgroup = api_fwaas_v2.firewall_group_get(self.request,
+                                                            firewallgroup_id)
             return firewallgroup
         except Exception:
             redirect = self.success_url
-            msg = _('Unable to retrieve firewallgroup details.')
+            msg = _('Unable to retrieve firewall group details.')
             exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_initial(self):
         firewallgroup = self._get_object()
-        initial = firewallgroup.get_dict()
+        initial = firewallgroup.to_dict()
         return initial
 
 
@@ -401,7 +400,7 @@ class InsertRuleToPolicyView(forms.ModalFormView):
 
     def get_initial(self):
         policy = self._get_object()
-        initial = policy.get_dict()
+        initial = policy.to_dict()
         initial['policy_id'] = initial['id']
         return initial
 
@@ -440,40 +439,6 @@ class RemoveRuleFromPolicyView(forms.ModalFormView):
 
     def get_initial(self):
         policy = self._get_object()
-        initial = policy.get_dict()
+        initial = policy.to_dict()
         initial['policy_id'] = initial['id']
         return initial
-
-
-class RouterCommonView(forms.ModalFormView):
-    form_id = "update_firewall_form"
-    context_object_name = 'firewall'
-    submit_label = _("Save Changes")
-    success_url = reverse_lazy("horizon:project:firewalls_v2:index")
-
-    def get_context_data(self, **kwargs):
-        context = super(RouterCommonView,
-                        self).get_context_data(**kwargs)
-        context["firewall_id"] = self.kwargs['firewall_id']
-        args = (self.kwargs['firewall_id'],)
-        context['submit_url'] = reverse(self.submit_url, args=args)
-        obj = self._get_object()
-        if obj:
-            context['name'] = obj.name_or_id
-        return context
-
-    @memoized.memoized_method
-    def _get_object(self, *args, **kwargs):
-        firewall_id = self.kwargs['firewall_id']
-        try:
-            firewall = api_fwaas_v2.firewall_get(self.request, firewall_id)
-            return firewall
-        except Exception:
-            redirect = self.success_url
-            msg = _('Unable to retrieve firewall details.')
-            exceptions.handle(self.request, msg, redirect=redirect)
-
-    def get_initial(self):
-        firewall = self._get_object()
-        initial = firewall.get_dict()
-        return initial
